==> deepin-fcitx5configtool-plugin_6.0.11.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_hi_IN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>एडॉन्स</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>उन्नत निर्देश</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="40"/>
        <source>"Advanced Settings" is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>"उन्नत निर्देश" केवल वह इनपुट मेथड लेती है जो सिस्टम सेटिंग्स का उपयोग करती है, यदि इनपुट मेथड के अपने सेटिंग्स हैं, तो अपने सेटिंग्स वाली सेटिंग्स विशेष रूप से लागू होती हैं।</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="53"/>
        <source>Global Config</source>
        <translation>ग्लोबल कॉन्फ़िग</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="69"/>
        <source>Add-ons</source>
        <translation>एडॉन्स</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="150"/>
        <source>Please enter a new shortcut</source>
        <translation>कृपया एक नया शॉर्टकट दर्ज करें</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>ऊपर ले जाएं</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>नीचे ले जाएं</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>हटाएं</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>इनपुट मेथड जोड़ें</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>खोज</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>ऐप स्टोर में अधिक खोजें</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>जोड़ें</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>इनपुट मेथड प्रबंधन</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>इनपुट मेथड जोड़ें</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>शॉर्टकट्स</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="49"/>
        <source>Restore Defaults</source>
        <translation>डिफ़ॉल्ट वापस ले आएं</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="101"/>
        <source>Scroll between input methods</source>
        <translation>इनपुट मेथड के बीच स्क्रॉल करें</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Turn on or off input methods</source>
        <translation>इनपुट मेथड चालू या बंद करें</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="135"/>
        <source>Please enter a new shortcut</source>
        <translation>कृपया एक नया शॉर्टकट दर्ज करें</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="162"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>यह वर्तमान में उपयोग किए जा रहे इनपुट मेथड को चालू या बंद करता है। यदि कोई इनपुट मेथड उपयोग में नहीं है या पहला इनपुट मेथड कीबोर्ड नहीं है, तो यह पहले इनपुट मेथड और वर्तमान में उपयोग किए जा रहे कीबोर्ड/इनपुट मेथड के बीच बदल जाता है।</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>इनपुट मेथड</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>इनपुट मेथड प्रबंधन, इनपुट मेथड शॉर्टकट्स, उन्नत निर्देश</translation>
    </message>
</context>
</TS>

==> deepin-fcitx5configtool-plugin_6.0.12.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>एडॉन्स</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>उन्नत निर्देश</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;उन्नत निर्देश&quot; केवल वह इनपुट मेथड लेती है जो सिस्टम सेटिंग्स का उपयोग करती है, यदि इनपुट मेथड के अपने सेटिंग्स हैं, तो अपने सेटिंग्स वाली सेटिंग्स विशेष रूप से लागू होती हैं।</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation>ग्लोबल कॉन्फ़िग</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation>एडॉन्स</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation>कृपया एक नया शॉर्टकट दर्ज करें</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation>ऊपर ले जाएं</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation>नीचे ले जाएं</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation>हटाएं</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation>इनपुट मेथड जोड़ें</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation>खोज</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation>ऐप स्टोर में अधिक खोजें</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation>जोड़ें</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>इनपुट मेथड प्रबंधन</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation>इनपुट मेथड जोड़ें</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>शॉर्टकट्स</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation>डिफ़ॉल्ट वापस ले आएं</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation>इनपुट मेथड के बीच स्क्रॉल करें</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation>इनपुट मेथड चालू या बंद करें</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation>कृपया एक नया शॉर्टकट दर्ज करें</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>यह वर्तमान में उपयोग किए जा रहे इनपुट मेथड को चालू या बंद करता है। यदि कोई इनपुट मेथड उपयोग में नहीं है या पहला इनपुट मेथड कीबोर्ड नहीं है, तो यह पहले इनपुट मेथड और वर्तमान में उपयोग किए जा रहे कीबोर्ड/इनपुट मेथड के बीच बदल जाता है।</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>इनपुट मेथड</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>इनपुट मेथड प्रबंधन, इनपुट मेथड शॉर्टकट्स, उन्नत निर्देश</translation>
    </message>
</context>
</TS>
